<a href="https://cognite.com/">
    <img src="https://github.com/cognitedata/cognite-sdk-python/blob/master/cognite_logo.png" alt="Cognite logo" title="Cognite" align="right" height="80" />
</a>

ML Dev
===============

Data Science tools and algorithms developed at Cognite.

## Setup
#### Get code from github
```bash
$ git clone git@github.com:cognitedata/ml-toolkit.git
```

```
#### Activate virtual environment and install dependencies from Pipfile.lock
```bash
$ pipenv shell
$ pipenv sync --dev
```